@@ -56,7 +56,7 @@ class Geo_common:
                 if not tmp: continue                                   # 允许出现空值 , 并直接跳过
                 tmp = tmp.strip().split(";")                           # group , raw_file_r1 , raw_file_r2 可以输入多个值, 用 ; 分割
                 if len(tmp) == 1 :
-                    self.samples[line[0]][head] = tmp
+                    self.samples[line[0]][head] = tmp[0]
                 else:
                     self.samples[line[0]][head] = []
                     for i in tmp:
